==> v0.3.0.zip: epervier-old/examples/menus/options/init.lua <==
-- scenes/options :: a basic example of how to handle gamecore options in a menu

--[[
  Copyright © 2019 Kazhnuz

  Permission is hereby granted, free of charge, to any person obtaining a copy of
  this software and associated documentation files (the "Software"), to deal in
  the Software without restriction, including without limitation the rights to
  use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
  the Software, and to permit persons to whom the Software is furnished to do so,
  subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
  FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
]]

local Scene     = require "gamecore.modules.scenes"
local OptionsMenu  = Scene:extend()

local ListBox   = require "gamecore.modules.menusystem.listbox"
local Widgets   = require "examples.menus.options.widgets"

function OptionsMenu:new()
  OptionsMenu.super.new(self)
  self.assets:addImageFont("medium", "examples/mainmenu/assets/medium")
  self.assets:setMusic("examples/menus/options/assets/music.ogg")

  self.assets:addSFX("navigate",  "examples/mainmenu/assets/menu_move.mp3")
  self.assets:addSFX("confirm",   "examples/mainmenu/assets/menu_confirm.mp3")
  self.assets:addSFX("cancel",    "examples/mainmenu/assets/menu_error.mp3")

  self.assets:playMusic()

  self:addMenu("main", true)
  self:addSubMenu("video", "video")
  self:addSubMenu("audio", "audio")
  self:addSubMenu("langs", "langs")
  self:addSubMenu("inputs", "inputs")

  Widgets.Resolution(self, "video")
  Widgets.Switch(self, "video", "fullscreen")
  Widgets.Switch(self, "video", "borders")
  Widgets.Switch(self, "video", "vsync")

  self:addPlayerMenus()

  self:setLanguageMenu()

  Widgets.Audio(self, "audio", "sfx")
  Widgets.Audio(self, "audio", "music")

  Widgets.Exit(self, "main")
  self.menusystem:switchMenu("main")

  self.menusystem:setSoundFromSceneAssets("navigate")

  self.keyDetector = {}
  self.keyDetector.widget = nil
end

-- MENU FUNCTION
-- Functions that serve the handling of menus

function OptionsMenu:addMenu(name, nobackbutton)
  local screenHeight, screenWidth = core.screen:getDimensions()
  local w, h = 424/2, 240 - 48
  local x, y = w / 2, 24
  ListBox(self.menusystem, name, x, y, w, h, 8)
end

function OptionsMenu:addSubMenu(name, fullname)
  self:addMenu(name)
  Widgets.SubMenu(self, "main", name, fullname)
  Widgets.SubMenu(self, name, "main", "back", 1, "<")
end

function OptionsMenu:addPlayerMenus()
  for i,v in ipairs(core.input.data) do
    local menu = "player" .. i
    self:addMenu(menu)
    Widgets.PlayerSubMenu(self, "inputs", i)
    for k,w in pairs(v.keys) do
      -- FIXME: make sure that you can use the order you want for the keys list
      -- instead of a random one
      Widgets.Key(self, i, k)
    end
    Widgets.SubMenu(self, menu, "inputs", "back", 1, "<")
  end
end

function OptionsMenu:addScene(submenu, scene, fullname)
  Widgets.Dummy(self, submenu, fullname)
end

function OptionsMenu:setLanguageMenu()
  for i,v in ipairs(core.lang.data.available) do
    Widgets.Lang(self, "langs", v)
  end
end

function OptionsMenu:changeKey(widget)
  self.keyDetector.isActive = true
  self.keyDetector.widget = widget
end

function OptionsMenu:keypressed( key )
  if (self.keyDetector.isActive) then
    self.keyDetector.widget:receiveKey( key )
    self.menusystem:activate()
    self.keyDetector.isActive = false
  end
end

function OptionsMenu:draw()
  love.graphics.setColor(.3,  .1, .4, 1)
  love.graphics.rectangle("fill", 0, 0, 424, 240)
end

return OptionsMenu

==> v0.6.0rc1.zip: epervier-old/examples/menus/options/init.lua <==
-- scenes/options :: a basic example of how to handle gamecore options in a menu

--[[
  Copyright © 2019 Kazhnuz

  Permission is hereby granted, free of charge, to any person obtaining a copy of
  this software and associated documentation files (the "Software"), to deal in
  the Software without restriction, including without limitation the rights to
  use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
  the Software, and to permit persons to whom the Software is furnished to do so,
  subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
  FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
  IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
]]

local Scene     = require "gamecore.modules.scenes"
local OptionsMenu  = Scene:extend()

local ListBox   = require "gamecore.modules.menusystem.listbox"
local Widgets   = require "examples.menus.options.widgets"

function OptionsMenu:new()
  OptionsMenu.super.new(self)
  self.assets:addImageFont("medium", "assets/fonts/medium")
  self.assets:setMusic("assets/music/music.ogg")

  self.assets:addSFX("navigate",  "assets/sfx/menu_move.mp3")
  self.assets:addSFX("confirm",   "assets/sfx/menu_confirm.mp3")
  self.assets:addSFX("cancel",    "assets/sfx/menu_error.mp3")

  self.assets:playMusic()

  self:addMenu("main", true)
  self:addSubMenu("video", "video")
  self:addSubMenu("audio", "audio")
  self:addSubMenu("langs", "langs")
  self:addSubMenu("inputs", "inputs")

  Widgets.Resolution(self, "video")
  Widgets.Switch(self, "video", "fullscreen")
  Widgets.Switch(self, "video", "borders")
  Widgets.Switch(self, "video", "vsync")

  self:addPlayerMenus()

  self:setLanguageMenu()

  Widgets.Audio(self, "audio", "sfx")
  Widgets.Audio(self, "audio", "music")

  Widgets.Exit(self, "main")
  self.menusystem:switchMenu("main")

  self.menusystem:setSoundFromSceneAssets("navigate")

  self.keyDetector = {}
  self.keyDetector.widget = nil
end

-- MENU FUNCTION
-- Functions that serve the handling of menus

function OptionsMenu:addMenu(name, nobackbutton)
  local screenHeight, screenWidth = core.screen:getDimensions()
  local w, h = 424/2, 240 - 48
  local x, y = w / 2, 24
  ListBox(self.menusystem, name, x, y, w, h, 8)
end

function OptionsMenu:addSubMenu(name, fullname)
  self:addMenu(name)
  Widgets.SubMenu(self, "main", name, fullname)
  Widgets.SubMenu(self, name, "main", "back", 1, "<")
end

function OptionsMenu:addPlayerMenus()
  for i,v in ipairs(core.input.data) do
    local menu = "player" .. i
    self:addMenu(menu)
    Widgets.PlayerSubMenu(self, "inputs", i)
    for k,w in pairs(v.keys) do
      -- FIXME: make sure that you can use the order you want for the keys list
      -- instead of a random one
      Widgets.Key(self, i, k)
    end
    Widgets.SubMenu(self, menu, "inputs", "back", 1, "<")
  end
end

function OptionsMenu:addScene(submenu, scene, fullname)
  Widgets.Dummy(self, submenu, fullname)
end

function OptionsMenu:setLanguageMenu()
  for i,v in ipairs(core.lang.data.available) do
    Widgets.Lang(self, "langs", v)
  end
end

function OptionsMenu:changeKey(widget)
  self.keyDetector.isActive = true
  self.keyDetector.widget = widget
end

function OptionsMenu:keypressed( key )
  if (self.keyDetector.isActive) then
    self.keyDetector.widget:receiveKey( key )
    self.menusystem:activate()
    self.keyDetector.isActive = false
  end
end

function OptionsMenu:draw()
  love.graphics.setColor(.3,  .1, .4, 1)
  love.graphics.rectangle("fill", 0, 0, 424, 240)
end

return OptionsMenu
